@@ -1,8 +1,8 @@
 # Copyright (C) Kevin R. Coombes, 2007-2012
 
 setClass('ClusterTest',
-         representation(call='call',
-                        result='matrix'))
+         slots = c(call='call',
+                   result='matrix'))
 
 .getUpperTriValues <- function(data) {
   n <- nrow(data)
